@@ -162,6 +162,8 @@ lws_create_context(struct lws_context_creation_info *info)
 			return NULL;
 		}
 
+		context->pt[n].context = context;
+		context->pt[n].tid = n;
 		context->pt[n].http_header_data = lws_malloc(context->max_http_header_data *
 						       context->max_http_header_pool);
 		if (!context->pt[n].http_header_data)
