@@ -53,11 +53,12 @@ lws_free_wsi(struct lws *wsi)
 	lws_free_set_NULL(wsi->rxflow_buffer);
 	lws_free_set_NULL(wsi->trunc_alloc);
 
-	if (wsi->u.hdr.ah) {
+	if (wsi->u.hdr.ah)
 		/* we're closing, losing some rx is OK */
 		wsi->u.hdr.ah->rxpos = wsi->u.hdr.ah->rxlen;
-		lws_header_table_detach(wsi);
-	}
+
+	/* we may not have an ah, but may be on the waiting list... */
+	lws_header_table_detach(wsi);
 
 	wsi->context->count_wsi_allocated--;
 	lwsl_debug("%s: %p, remaining wsi %d\n", __func__, wsi,
@@ -71,14 +72,17 @@ lws_remove_from_timeout_list(struct lws *wsi)
 {
 	struct lws_context_per_thread *pt = &wsi->context->pt[(int)wsi->tsi];
 
-	if (!wsi->timeout_list_prev)
+	if (!wsi->timeout_list_prev) /* ie, not part of the list */
 		return;
 
 	lws_pt_lock(pt);
+	/* if we have a next guy, set his prev to our prev */
 	if (wsi->timeout_list)
 		wsi->timeout_list->timeout_list_prev = wsi->timeout_list_prev;
+	/* set our prev guy to our next guy instead of us */
 	*wsi->timeout_list_prev = wsi->timeout_list;
 
+	/* we're out of the list, we should not point anywhere any more */
 	wsi->timeout_list_prev = NULL;
 	wsi->timeout_list = NULL;
 	lws_pt_unlock(pt);
@@ -104,11 +108,15 @@ lws_set_timeout(struct lws *wsi, enum pending_timeout reason, int secs)
 
 	time(&now);
 
-	if (!wsi->pending_timeout && reason) {
+	if (reason && !wsi->timeout_list_prev) {
+		/* our next guy is current first guy */
 		wsi->timeout_list = pt->timeout_list;
+		/* if there is a next guy, set his prev ptr to our next ptr */
 		if (wsi->timeout_list)
 			wsi->timeout_list->timeout_list_prev = &wsi->timeout_list;
+		/* our prev ptr is first ptr */
 		wsi->timeout_list_prev = &pt->timeout_list;
+		/* set the first guy to be us */
 		*wsi->timeout_list_prev = wsi;
 	}
 
@@ -299,11 +307,16 @@ just_kill_connection:
 		n = shutdown(wsi->sock, SHUT_WR);
 		if (n)
 			lwsl_debug("closing: shutdown ret %d\n", LWS_ERRNO);
-		wsi->state = LWSS_SHUTDOWN;
-		lws_change_pollfd(wsi, LWS_POLLOUT, LWS_POLLIN);
-		lws_set_timeout(wsi, PENDING_TIMEOUT_SHUTDOWN_FLUSH,
-				context->timeout_secs);
-		return;
+
+		/* libuv: no event available to guarantee completion */
+		if (!LWS_LIBUV_ENABLED(context)) {
+
+			lws_change_pollfd(wsi, LWS_POLLOUT, LWS_POLLIN);
+			wsi->state = LWSS_SHUTDOWN;
+			lws_set_timeout(wsi, PENDING_TIMEOUT_SHUTDOWN_FLUSH,
+					context->timeout_secs);
+			return;
+		}
 	}
 #endif
 
@@ -372,7 +385,9 @@ just_kill_connection:
 	    ((wsi->state_pre_close == LWSS_ESTABLISHED) ||
 	    (wsi->state_pre_close == LWSS_RETURNED_CLOSE_ALREADY) ||
 	    (wsi->state_pre_close == LWSS_AWAITING_CLOSE_ACK) ||
-	    (wsi->state_pre_close == LWSS_FLUSHING_STORED_SEND_BEFORE_CLOSE))) {
+	    (wsi->state_pre_close == LWSS_FLUSHING_STORED_SEND_BEFORE_CLOSE) ||
+	    (wsi->mode == LWSCM_WS_CLIENT && wsi->state_pre_close == LWSS_HTTP) ||
+	    (wsi->mode == LWSCM_WS_SERVING && wsi->state_pre_close == LWSS_HTTP))) {
 		lwsl_debug("calling back CLOSED\n");
 		wsi->protocol->callback(wsi, LWS_CALLBACK_CLOSED,
 					wsi->user_space, NULL, 0);
@@ -922,18 +937,39 @@ lws_ensure_user_space(struct lws *wsi)
 
 LWS_VISIBLE void lwsl_emit_stderr(int level, const char *line)
 {
+	time_t o_now = time(NULL);
 	unsigned long long now;
+	struct tm *ptm = NULL;
 	char buf[300];
+#ifndef WIN32
+	struct tm tm;
+#endif
 	int n;
 
+#ifdef WIN32
+	ptm = localtime(&o_now);
+#else
+	if (localtime_r(&o_now, &tm))
+		ptm = &tm;
+#endif
 	buf[0] = '\0';
 	for (n = 0; n < LLL_COUNT; n++) {
 		if (level != (1 << n))
 			continue;
 		now = time_in_microseconds() / 100;
-		sprintf(buf, "[%llu:%04d] %s: ",
-			(unsigned long long) now / 10000,
-			(int)(now % 10000), log_level_names[n]);
+		if (ptm)
+			sprintf(buf, "[%04d/%02d/%02d %02d:%02d:%02d:%04d] %s: ",
+				ptm->tm_year + 1900,
+				ptm->tm_mon,
+				ptm->tm_mday,
+				ptm->tm_hour,
+				ptm->tm_min,
+				ptm->tm_sec,
+				(int)(now % 10000), log_level_names[n]);
+		else
+			sprintf(buf, "[%llu:%04d] %s: ",
+					(unsigned long long) now / 10000,
+					(int)(now % 10000), log_level_names[n]);
 		break;
 	}
 
