@@ -530,6 +530,7 @@ struct lws_context_per_thread {
 	struct lws *rx_draining_ext_list;
 	struct lws *tx_draining_ext_list;
 	struct lws *timeout_list;
+	struct lws_context *context;
 	void *http_header_data;
 	struct allocated_headers *ah_pool;
 	struct lws *ah_wait_list;
@@ -546,6 +547,7 @@ struct lws_context_per_thread {
 #if defined(LWS_USE_LIBUV)
 	uv_loop_t *io_loop_uv;
 	uv_signal_t signals[8];
+	uv_timer_t uv_timeout_watcher;
 #endif
 #if defined(LWS_USE_LIBEV)
 	struct lws_io_watcher w_accept;
@@ -571,6 +573,7 @@ struct lws_context_per_thread {
 	unsigned int fds_count;
 
 	short ah_count_in_use;
+	unsigned char tid;
 };
 
 /*
@@ -948,12 +951,11 @@ struct _lws_header_related {
 	char post_literal_equal;
 	unsigned char parser_state; /* enum lws_token_indexes */
 	char redirects;
-	char more_rx_waiting;
 };
 
 struct _lws_websocket_related {
 	/* cheapest way to deal with ah overlap with ws union transition */
-	struct _lws_header_related *hdr;
+	struct _lws_header_related hdr;
 	char *rx_ubuf;
 	unsigned int rx_ubuf_alloc;
 	struct lws *rx_draining_ext_list;
@@ -1056,6 +1058,7 @@ struct lws {
 	unsigned int user_space_externally_allocated:1;
 	unsigned int socket_is_permanently_unusable:1;
 	unsigned int rxflow_change_to:2;
+	unsigned int more_rx_waiting:1; /* has to live here since ah may stick to end */
 #ifndef LWS_NO_EXTENSIONS
 	unsigned int extension_data_pending:1;
 #endif
